@@ -72,6 +72,20 @@ def md5_of_content(cont):
     hash_md5.update(cont)
     return hash_md5.hexdigest()
 
+def b64decode(s):
+    try:
+        return base64.b64decode(s)
+    except:
+        return s
+    pass
+
+def b64encode(s):
+    try:
+        return base64.b64encode(s)
+    except:
+        return s
+    pass
+
 
 
 def get_private_key( key ):
@@ -125,7 +139,7 @@ def get_exec_connection(config):
             ssh_client.connect( hostname   =  config['server_address'],
                             port       =  config['server_port'], 
                             username   =  config['auth_username'], 
-                            password   =  base64.b64decode( config['auth_password'] ) )
+                            password   =  b64decode( config['auth_password'] ) )
             pass
 
         else:
@@ -858,7 +872,7 @@ async def get_ssh_connection(websocket, config, ckey='', page_id = ''):
             client.connect( hostname   =  config['server_address'],
                             port       =  config['server_port'], 
                             username   =  config['auth_username'], 
-                            password   =  base64.b64decode( config['auth_password'] ) )
+                            password   =  b64decode( config['auth_password'] ) )
             pass
         else:
             log("connect with no auth provided")
@@ -945,7 +959,7 @@ async def get_sftp_connection(websocket, config, ckey='', page_id = ''):
         elif config.get('auth_password',None):
             #print("connect with auth password", config['auth_password'])
             t.connect( username=config['auth_username'],
-                       password=base64.b64decode(config['auth_password']))
+                       password=b64decode(config['auth_password']))
             pass
         else:
             log("connect with no auth provided")
@@ -1227,7 +1241,7 @@ async def sftp_prepare_files(infos, sftp, message, websocket):
                 data = list(map(lambda x:float(x), data, ))
                 pass
             elif value_type == 'base64':
-                data        = base64.b64encode(data)
+                data        = b64encode(data)
                 #print('data get is:', type(data)  )
                 data        = data.decode()
             pass
